@@ -1,8 +1,9 @@
 package Kelp::Module::Config::YAML;
-use Kelp::Base 'Kelp::Module::Config';
-use YAML 'LoadFile';
 
-our $VERSION = 0.01;
+use Kelp::Base 'Kelp::Module::Config';
+use YAML::PP qw(LoadFile);
+
+our $VERSION = '1.00';
 
 attr ext => 'yml';
 
@@ -29,9 +30,20 @@ Kelp::Module::Config::YAML - YAML config files for your Kelp app
     my $app = MyApp->new( config_module => 'Config::YAML' );
     $app->run;
 
+=head1 DESCRIPTION
+
+Works exactly the same as L<Kelp::Module::Config>, but loads configuration from
+YAML files with C<.yml> extension.
+
 =head1 SEE ALSO
 
-L<Kelp>, L<Kelp::Module>, L<Kelp::Module::Config>
+L<Kelp>
+
+L<Kelp::Module>
+
+L<Kelp::Module::Config>
+
+L<YAML::PP>
 
 =head1 AUTHOR
 
@@ -42,3 +54,4 @@ Stefan Geneshky minimal@cpan.org
 Perl
 
 =cut
+
